================
Libgetar C++ API
================

.. contents::
   :local:

GTAR
====

.. doxygenclass:: gtar::GTAR
   :members:

Record
======

.. doxygenclass:: gtar::Record
   :members:

Enums: Behavior, Format, Resolution
===================================

.. doxygenenum:: gtar::Behavior

.. doxygenenum:: gtar::Format

.. doxygenenum:: gtar::Resolution

SharedArray
===========

.. doxygenclass:: gtar::SharedArray
   :members:
